@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 require 'cucumber/core/test/result'
-require 'cucumber/core/test/duration_matcher'
+require 'support/duration_matcher'
 
 module Cucumber
   module Core
@@ -14,15 +14,19 @@ module Cucumber
           subject(:result) { described_class.new(duration) }
           let(:duration)   { Result::Duration.new(1 * 1000 * 1000) }
 
-          it 'describes itself to a visitor' do
+          before do
+            allow(visitor).to receive(:duration)
+            allow(visitor).to receive(:passed)
+          end
+
+          it 'is described as a passing test' do
             expect(visitor).to receive(:passed).with(args)
-            expect(visitor).to receive(:duration).with(duration, args)
 
             result.describe_to(visitor, args)
           end
 
           it 'converts to a string' do
-            expect(result.to_s).to eq '✓'
+            expect(result.to_s).to eq('✓')
           end
 
           it 'converts to a `Cucumber::Message::TestResult`' do
@@ -57,16 +61,26 @@ module Cucumber
           let(:duration)   { Result::Duration.new(1 * 1000 * 1000) }
           let(:exception)  { StandardError.new('error message') }
 
-          it 'describes itself to a visitor' do
+          before do
+            allow(visitor).to receive(:failed)
+            allow(visitor).to receive(:duration)
+            allow(visitor).to receive(:exception)
+          end
+
+          it 'is described as a failing test' do
             expect(visitor).to receive(:failed).with(args)
-            expect(visitor).to receive(:duration).with(duration, args)
+
+            result.describe_to(visitor, args)
+          end
+
+          it 'contains an exception message' do
             expect(visitor).to receive(:exception).with(exception, args)
 
             result.describe_to(visitor, args)
           end
 
           it 'has a duration' do
-            expect(result.duration).to eq duration
+            expect(result.duration).to eq(duration)
           end
 
           it 'converts to a Cucumber::Message::TestResult' do
@@ -371,14 +385,16 @@ module Cucumber
           describe '#merge!' do
             let(:merged_configuration) { described_class.new }
 
-            it 'sets the not default values from the argument accordingly' do
+            before do
               strict_configuration.set_strict(false, :undefined)
               strict_configuration.set_strict(false, :pending)
               strict_configuration.set_strict(true, :flaky)
               merged_configuration.set_strict(true, :pending)
               merged_configuration.set_strict(false, :flaky)
               strict_configuration.merge!(merged_configuration)
+            end
 
+            it 'sets the not default values from the argument accordingly' do
               expect(strict_configuration).not_to be_strict(:undefined)
               expect(strict_configuration).to be_strict(:pending)
               expect(strict_configuration).not_to be_strict(:flaky)
@@ -406,6 +422,7 @@ module Cucumber
 
           it 'counts passed results' do
             passed.describe_to(summary)
+
             expect(summary.total_passed).to eq(1)
             expect(summary.total(:passed)).to eq(1)
             expect(summary.total).to eq(1)
@@ -413,6 +430,7 @@ module Cucumber
 
           it 'counts skipped results' do
             skipped.describe_to(summary)
+
             expect(summary.total_skipped).to eq(1)
             expect(summary.total(:skipped)).to eq(1)
             expect(summary.total).to eq(1)
@@ -420,12 +438,13 @@ module Cucumber
 
           it 'counts undefined results' do
             undefined.describe_to(summary)
+
             expect(summary.total_undefined).to eq(1)
             expect(summary.total(:undefined)).to eq(1)
             expect(summary.total).to eq(1)
           end
 
-          it 'counts arbitrary raiseable results' do
+          it 'counts arbitrary raisable results' do
             flickering = Class.new(Result::Raisable) do
               def describe_to(visitor, *args)
                 visitor.flickering(*args)
@@ -433,12 +452,13 @@ module Cucumber
             end
 
             flickering.new.describe_to(summary)
+
             expect(summary.total_flickering).to eq(1)
             expect(summary.total(:flickering)).to eq(1)
             expect(summary.total).to eq(1)
           end
 
-          it 'returns zero for a status where no messges have been received' do
+          it 'returns zero for a status where no messages have been received' do
             expect(summary.total_passed).to eq(0)
             expect(summary.total(:passed)).to eq(0)
             expect(summary.total_ponies).to eq(0)
@@ -447,11 +467,12 @@ module Cucumber
 
           it "doesn't count unknown results" do
             unknown.describe_to(summary)
+
             expect(summary.total).to eq(0)
           end
 
           it 'counts combinations' do
-            [passed, passed, failed, skipped, undefined].each { |r| r.describe_to(summary) }
+            [passed, passed, failed, skipped, undefined].each { |result| result.describe_to(summary) }
 
             expect(summary.total).to eq(5)
             expect(summary.total_passed).to eq(2)
@@ -461,14 +482,16 @@ module Cucumber
           end
 
           it 'records durations' do
-            [passed, failed].each { |r| r.describe_to(summary) }
+            [passed, failed].each { |result| result.describe_to(summary) }
+
             expect(summary.durations[0]).to be_duration(11)
             expect(summary.durations[1]).to be_duration(10)
           end
 
           it 'records exceptions' do
-            [passed, failed].each { |r| r.describe_to(summary) }
-            expect(summary.exceptions).to eq [exception]
+            [passed, failed].each { |result| result.describe_to(summary) }
+
+            expect(summary.exceptions).to eq([exception])
           end
 
           describe '#ok?' do
@@ -492,6 +515,7 @@ module Cucumber
 
             it 'pending result is ok if not strict' do
               pending.describe_to(summary)
+
               expect(summary.ok?).to be true
               strict = Result::StrictConfiguration.new([:pending])
               expect(summary.ok?(strict: strict)).to be false
@@ -499,6 +523,7 @@ module Cucumber
 
             it 'undefined result is ok if not strict' do
               undefined.describe_to(summary)
+
               expect(summary.ok?).to be true
               strict = Result::StrictConfiguration.new([:undefined])
               expect(summary.ok?(strict: strict)).to be false
